# testreportng

![CI Status](https://github.com/williamfzc/testreportng/workflows/Python%20application/badge.svg)  
[![codecov](https://codecov.io/gh/williamfzc/testreportng/branch/master/graph/badge.svg?token=18PMrmYcAk)](https://codecov.io/gh/williamfzc/testreportng)

next generation of test report, for unittest.
